pub struct FilteredResourcesBuilder<'w> { /* private fields */ }๐Deprecated since 0.20.0:
Use QueryBuilder instead.
Builder struct to define the access for a FilteredResources.
This is passed to a callback in FilteredResourcesParamBuilder.
Implementations
Sourceimpl<'w> FilteredResourcesBuilder<'w>
impl<'w> FilteredResourcesBuilder<'w>
Sourcepub fn add_read_all(&mut self) -> &mut Self
pub fn add_read_all(&mut self) -> &mut Self
Add accesses required to read all resources.
Sourcepub fn add_read<R: Resource>(&mut self) -> &mut Self
pub fn add_read<R: Resource>(&mut self) -> &mut Self
Add accesses required to read the resource of the given type.
Sourcepub fn add_read_by_id(&mut self, component_id: ComponentId) -> &mut Self
pub fn add_read_by_id(&mut self, component_id: ComponentId) -> &mut Self
Add accesses required to read the resource with the given ComponentId.