FilteredResourcesMutBuilder

Struct FilteredResourcesMutBuilder 

pub struct FilteredResourcesMutBuilder<'w> { /* private fields */ }
๐Ÿ‘ŽDeprecated since 0.20.0:

Use QueryBuilder instead.

Builder struct to define the access for a FilteredResourcesMut.

This is passed to a callback in FilteredResourcesMutParamBuilder.

Implementations

Source

impl<'w> FilteredResourcesMutBuilder<'w>

pub fn new(world: &'w mut World) -> Self

Creates a new builder with no access.

pub fn access(&self) -> &Access

Returns a reference to the underlying Access.

pub fn add_read_all(&mut self) -> &mut Self

Add accesses required to read all resources.

pub fn add_read<R: Resource>(&mut self) -> &mut Self

Add accesses required to read the resource of the given type.

pub fn add_read_by_id(&mut self, component_id: ComponentId) -> &mut Self

Add accesses required to read the resource with the given ComponentId.

pub fn add_write_all(&mut self) -> &mut Self

Add accesses required to get mutable access to all resources.

pub fn add_write<R: Resource>(&mut self) -> &mut Self

Add accesses required to get mutable access to the resource of the given type.

pub fn add_write_by_id(&mut self, component_id: ComponentId) -> &mut Self

Add accesses required to get mutable access to the resource with the given ComponentId.

pub fn build(self) -> Access

Create an Access that represents the accesses of the builder.